#!/bin/sh
# A high-speed character set detection library
#
SRC_URL=http://mirror.billymays.us/libguess
#
# script by: til <rob D0T til D0T freedman AT googlemail D0T com>
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb
#
set -u -e -x

#libguess
version=1.0
build=66.1
arch=i486
tune=i686

pkgname=libguess-$version
package=$pkgname-$arch-$build

PKG_SRC="$REPO/extra/l/libguess/build-libguess.sh
$SRC_URL/libguess-$version.tgz"

CWD=`pwd`
TMP=${TMP:-$CWD/tmp}
PKG=$TMP/$package
SRC=$TMP/$pkgname

[ -d $SRC ] && rm -fr $SRC
[ -d $PKG ] && rm -fr $PKG

### every package should have it
mkdir -p $PKG/{install,usr/{src,doc}/$pkgname}
#
mkdir $SRC
tar xf $CWD/libguess-$version.tgz --strip-components=1 -C $SRC
cd $SRC
#./autogen.sh
./configure --help >$CWD/configure-help

CFLAGS="-O2 -march=$arch -mtune=$tune" \
CXXFLAGS="-O2 -march=$arch -mtune=$tune" \
./configure \
   --prefix=/usr 

make || exit 1
make install DESTDIR=$PKG

# helperline
(cd $PKG;find . -printf "%M %u:%g %p %l\n" >$CWD/make.installed)

cp -a COPYING README $PKG/usr/doc/$pkgname
cd $PKG

# strip symbols
find . | xargs file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d :| xargs -r strip --strip-unneeded

find . | xargs file | grep "current ar archive" |\
	cut -f 1 -d : | xargs -r strip -g

#       |-----handy-ruler------------------------------------------------------|
cat << EOF > install/slack-desc
libguess: libguess (A high-speed character set detection library)
libguess:
libguess: libguess employs discrete-finite automata to deduce the character 
libguess: set of the input buffer. The advantage of this is that all character 
libguess: sets can be checked in parallel, and quickly. Right now, libguess 
libguess: passes a byte to each DFA on the same pass, meaning that the winning 
libguess: character set can be deduced as efficiently as possible.
EOF
cp $CWD/build-libguess.sh usr/src/$pkgname
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

cd $CWD
md5sum $package.txz >$package.md5
depfinder $PKG >$package.dep
echo  "$PKG_SRC"	> $package.src
